==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ADDRESSSEARCHTEXT.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STREETCRITERIA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ZONECRITERIA" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "streetcriteria",
    "zonecriteria"
})
@XmlRootElement(name = "ADDRESSSEARCHTEXT")
public class ADDRESSSEARCHTEXT {

    @XmlElement(name = "STREETCRITERIA")
    protected String streetcriteria;
    @XmlElement(name = "ZONECRITERIA")
    protected String zonecriteria;

    /**
     * Gets the value of the streetcriteria property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTREETCRITERIA() {
        return streetcriteria;
    }

    /**
     * Sets the value of the streetcriteria property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTREETCRITERIA(String value) {
        this.streetcriteria = value;
    }

    /**
     * Gets the value of the zonecriteria property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getZONECRITERIA() {
        return zonecriteria;
    }

    /**
     * Sets the value of the zonecriteria property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setZONECRITERIA(String value) {
        this.zonecriteria = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/ADDRESSSEARCHTEXT.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STREETCRITERIA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ZONECRITERIA" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "streetcriteria",
    "zonecriteria"
})
@XmlRootElement(name = "ADDRESSSEARCHTEXT")
public class ADDRESSSEARCHTEXT {

    @XmlElement(name = "STREETCRITERIA")
    protected String streetcriteria;
    @XmlElement(name = "ZONECRITERIA")
    protected String zonecriteria;

    /**
     * Obtient la valeur de la propriété streetcriteria.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTREETCRITERIA() {
        return streetcriteria;
    }

    /**
     * Définit la valeur de la propriété streetcriteria.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTREETCRITERIA(String value) {
        this.streetcriteria = value;
    }

    /**
     * Obtient la valeur de la propriété zonecriteria.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getZONECRITERIA() {
        return zonecriteria;
    }

    /**
     * Définit la valeur de la propriété zonecriteria.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setZONECRITERIA(String value) {
        this.zonecriteria = value;
    }

}
